package com.ruoyi.ems.service;

import java.util.List;
import com.ruoyi.ems.domain.CaEmissionForecast;

/**
 * 碳排放预测Service接口
 * 
 * @author ruoyi
 * @date 2024-08-12
 */
public interface ICaEmissionForecastService
{
    /**
     * 查询碳排放预测
     * 
     * @param id 碳排放预测主键
     * @return 碳排放预测
     */
     CaEmissionForecast selectCaEmissionForecastById(Long id);

    /**
     * 查询碳排放预测列表
     * 
     * @param caEmissionForecast 碳排放预测
     * @return 碳排放预测集合
     */
     List<CaEmissionForecast> selectCaEmissionForecastList(CaEmissionForecast caEmissionForecast);

    /**
     * 新增碳排放预测
     * 
     * @param caEmissionForecast 碳排放预测
     * @return 结果
     */
     int insertCaEmissionForecast(CaEmissionForecast caEmissionForecast);

    /**
     * 修改碳排放预测
     * 
     * @param caEmissionForecast 碳排放预测
     * @return 结果
     */
     int updateCaEmissionForecast(CaEmissionForecast caEmissionForecast);

    /**
     * 批量删除碳排放预测
     * 
     * @param ids 需要删除的碳排放预测主键集合
     * @return 结果
     */
     int deleteCaEmissionForecastByIds(Long[] ids);

    /**
     * 删除碳排放预测信息
     * 
     * @param id 碳排放预测主键
     * @return 结果
     */
     int deleteCaEmissionForecastById(Long id);
}
